SimdElement

Trait SimdElement 

pub trait SimdElement {
    type Mask: SimdElement;
}
Types that can be used as elements in SIMD vectors.

Required Associated Types

type Mask: SimdElement

The associated mask lane type. This will be a signed integer of the same size as this type.

Implementations on Foreign Types

Source

impl SimdElement for f32

Source

impl SimdElement for f64

Source

impl SimdElement for i8

Source

impl SimdElement for i16

Source

impl SimdElement for i32

Source

impl SimdElement for i64

Source

impl SimdElement for u8

Source

impl SimdElement for u16

Source

impl SimdElement for u32

Implementors